<?php
session_start();
$debugMode = 1;

require_once('osm-oauth.php');
require_once('dbutils.php');
$users = new GenericSqliteTable("var/users.db","users");
$userToId = new GenericSqliteTable("var/userToId.db","userToId");

//Check if user wants to clear their record in debug mode
if($debugMode and isset($_GET['zapme']))
{
	unset($users[$_SESSION['user_id']]);
	unset($userToId[$_SESSION['display_name']]);
	session_unset();	
	die("Records cleared. Try <a href='.'>reloading the page</a>.");
}


//Store association from user ID to display name
if(!isset($userToId[$_SESSION['display_name']]))
	$userToId[$_SESSION['display_name']] = array("id"=>$_SESSION['user_id']);

$userData = array();
if(isset($users[$_SESSION['user_id']]))
	$userData = $users[$_SESSION['user_id']];

//Read declarations into memory
$declarationFiles = glob("declarations/*.xml");
$declarations = array();
foreach($declarationFiles as $d)
{
	$xml = new SimpleXMLElement(file_get_contents($d));
	$expl = explode("/",$d);
	$declareId = substr($expl[1],0,strlen($expl[1])-4);
	$declarations[$declareId] = $xml;
}
//print_r($declarations);
?>
<link rel="stylesheet" type="text/css" href="default.css" />

<h1>License Declarations</h1>
<?php
echo "Welcome ".htmlspecialchars($_SESSION['display_name'])." (".$_SESSION['user_id'].")";

//Generate license characterstic icons
function XmlToIcons($d)
{
	$out = "";
	foreach($d->attributes() as $k => $v)
	{
		if($k == "creativecommons" and $v == "yes")
			$out .= '<a href="http://creativecommons.org/"><img src="icon/cc.png" height="20px" width="20px" alt="Creative Commons"/></a>';
		if($k == "by" and $v == "yes")
			$out .= '<img src="icon/by.png" height="20px" width="20px" alt="Attribution"/>';
		if($k == "sharealike" and $v == "yes")
			$out .= '<img src="icon/sa.png" height="20px" width="20px" alt="Sharealike"/>';
		if($k == "noderivs" and $v == "yes")
			$out .= '<img src="icon/nd.png" height="20px" width="20px" alt="No derivatives"/>';
		if($k == "noncommercial" and $v == "yes")
			$out .= '<img src="icon/nc.png" height="20px" width="20px" alt="Non-commercial"/>';
		if($k == "nolimits" and $v == "yes")
			$out .= '<img src="icon/zero.png" alt="No Limits" height="20px" width="20px"/>';
		if($k == "preferred" and $v == "yes")
			$out .= '<img src="icon/Dialog-information_on.png" alt="Preferred" height="20px" width="20px"/>';
 	}
	return $out;
}

//Display user's additional licenses
$myDeclarations = array();
if(isset($userData['declarations']))
	$myDeclarations = $userData['declarations'];
$declAccepted = array();
?>

<div style="float:right; margin: 10px 10px 10px 10px;">
<h3>Key</h3>
<p>
<a href="http://creativecommons.org/"><img src="icon/cc.png" height="20px" width="20px" alt="Creative Commons"/></a>
<a href="http://creativecommons.org/">Creative Commons</a><br/>
<img src="icon/by.png" height="20px" width="20px" alt="Attribution"/> Requires Attribution<br/>
<img src="icon/sa.png" height="20px" width="20px" alt="Sharealike"/> Requires Share-alike<br/>
<img src="icon/nd.png" height="20px" width="20px" alt="No derivatives"/> No derivatives allowed<br/>
<img src="icon/nc.png" height="20px" width="20px" alt="Non-commercial"/> No commerical use allowed<br/>
<img src="icon/zero.png" alt="No Limits" height="20px" width="20px"/> No limits to use<br/>
<img src="icon/Dialog-information_on.png" alt="Preferred" height="20px" width="20px"/> Recommended licenses<br/>
</p>
</div>

<?php
if(count($myDeclarations) > 0)
{
?>
<h2>Your Extra Licenses</h2>
<table border="1">
<tr><td>License</td><td>Date Accepted</td></tr>
<?php
foreach($myDeclarations as $d)
{
if(!in_array($d['license'],$declAccepted))
	array_push($declAccepted, (string)$d['license']);
$decl = $declarations[$d['license']];
echo "<tr>";
echo '<td><a href="view.php?declare='.$d['license'].'">'.$decl->name."</a> ".XmlToIcons($decl)."</td>";
echo "<td>".date(DATE_RFC822,$d['time'])."</td>";
echo "</tr>\n";
}
?>
</table>
<?php
}

//Show list of extra licenses
?>
<h2>View Additional Licenses</h2>
<ul>
<?php

foreach($declarations as $declareId => $d)
{
	if(in_array($declareId, $declAccepted)) continue; //Skip licenses already accepted
?>
<li><a href="details.php?declare=<?php echo $declareId; ?>"><?php echo $d->name; ?></a> <?php echo XmlToIcons($d);?></li>
<?php
}
?>
</ul>
<h2>Links</h2>
<p><a href="http://www.openstreetmap.org/user/<?php echo htmlspecialchars($_SESSION['display_name']);?>">Back to OSM Profile</a><br/>
<a href="declared.php?display_name=<?php echo htmlspecialchars($_SESSION['display_name']);?>">Your Machine Readable Record (by Display Name)</a><br/>
<a href="declared.php?user_id=<?php echo $_SESSION['user_id'];?>">Your Machine Readable Record (by User ID)</a></p>

<?php
if($debugMode)
{
?>
<h2>Debug Options</h2>
<p><a href="?zapme=yes">Zap My Records</a>: this clears database and session variables associated with your account. All licenses are cleared. This feature can be disabled by setting $debugMode to 0.</p>

<?php
}
?>
